@@ -147,6 +147,16 @@ class ContentApi extends BaseApi
 			case M3_VIEW_TYPE_CONTENT:		// 汎用コンテンツ
 				break;
 			case M3_VIEW_TYPE_PRODUCT:	// 製品
+				// ##### woocommerce.phpが呼ばれる前にWooCommerceで使用するオプション値は取得しておく #####
+				global $m3WpOptions;		// 初期値取得用
+				
+				$addonObj = $this->_getAddonObj(M3_VIEW_TYPE_PRODUCT);			// 製品
+				$m3WpOptions['woocommerce_calc_taxes'] = 'yes';					// 税処理を行う
+				$m3WpOptions['woocommerce_tax_display_shop'] ='incl';			// 消費税表示方法(税込み)
+				$m3WpOptions['woocommerce_currency'] = $addonObj->getConfig('default_currency');		// デフォルト通貨
+				$m3WpOptions['woocommerce_price_num_decimals'] = 0;				// 価格表示少数桁数
+				$m3WpOptions['woocommerce_price_thousand_sep'] = ',';			// 価格桁区切り
+				$m3WpOptions['woocommerce_price_display_suffix'] = $addonObj->getConfig('price_suffix');	// 価格表示接尾辞
 				require_once($this->gEnv->getWordpressRootPath() . '/plugins/woocommerce/woocommerce.php');
 				break;
 			case M3_VIEW_TYPE_BBS:	// BBS
@@ -532,6 +542,69 @@ class ContentApi extends BaseApi
 		}
 		return $wpTermObj;
 	}
+	/**
+	 * 商品情報を取得
+	 *
+	 * @param int		$id					商品ID
+	 * @param array     $rowProduct			商品レコード
+	 * @param array     $rowPrice			商品価格
+	 * @param array     $rowImage			商品画像
+	 * @param array     $rowStatus			商品ステータス
+	 * @param array     $rowCategory		商品カテゴリー
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getProductInfo($id, &$rowProduct, &$rowPrice, &$rowImage, &$rowStatus, &$rowCategory)
+	{
+		// アドオンオブジェクト取得
+		$addonObj = $this->_getAddonObj(M3_VIEW_TYPE_PRODUCT);			// 製品
+		
+		$ret = $addonObj->getProductInfo($id, $this->langId, $rowProduct, $rowPrice, $rowImage, $rowStatus, $rowCategory);
+		return $ret;
+	}
+	/**
+	 * 製品価格取得
+	 *
+	 * @param array  	$srcRows			価格リスト
+	 * @param string	$priceType			価格のタイプ
+	 * @return array						取得した価格行
+	 */
+	function getProductPrice($srcRows, $priceType)
+	{
+		for ($i = 0; $i < count($srcRows); $i++){
+			if ($srcRows[$i]['pp_price_type_id'] == $priceType){
+				return $srcRows[$i];
+			}
+		}
+		return array();
+	}
+	/**
+	 * 製品税タイプ取得
+	 *
+	 * @param array  	$productRow			製品レコード
+	 * @return string						課税タイプ(sales=課税(外税),空=課税なし)
+	 */
+	function getProductTaxType($productRow)
+	{
+		$taxType = $productRow['pt_tax_type_id'];
+		if ($taxType == 'notax') $taxType = '';			// 課税なしの場合は空で返す
+		return $taxType;
+	}
+	/**
+	 * 税率を取得
+	 *
+	 * @param string	$taxType	税種別
+	 * @return float				税率
+	 */
+	public function getTaxRate($taxType)
+	{
+		if (empty($taxType)) return 0;
+		
+		// アドオンオブジェクト取得
+		$addonObj = $this->_getAddonObj(M3_VIEW_TYPE_PRODUCT);			// 製品
+		
+		$rate = $addonObj->getTaxRate($taxType);
+		return $rate;
+	}
 	/**
 	 * DBから取得したデータを退避する
 	 *
@@ -607,6 +680,7 @@ class ContentApi extends BaseApi
 			$serial = $row['cn_serial'];
 			$id		= $row['cn_id'];
 			$title	= $row['cn_name'];
+			$excerpt = $row['cn_description'];			// 概要
 			$authorId		= $row['cn_create_user_id'];		// コンテンツ登録者
 			$authorName		= $row['lu_name'];				// コンテンツ登録者名
 			$authorUrl		= '';			// コンテンツ登録者URL
@@ -619,6 +693,7 @@ class ContentApi extends BaseApi
 			$serial = $row['be_serial'];
 			$id		= $row['be_id'];
 			$title	= $row['be_name'];
+			$excerpt = $row['be_description'];			// 概要
 			$authorId		= $row['be_regist_user_id'];		// コンテンツ登録者
 			$authorName		= $row['lu_name'];				// コンテンツ登録者名
 			$authorUrl		= '';			// コンテンツ登録者URL
@@ -631,11 +706,12 @@ class ContentApi extends BaseApi
 			$serial = $row['pt_serial'];
 			$id		= $row['pt_id'];
 			$title	= $row['pt_name'];
+			$excerpt = $row['pt_description'];			// 概要
 			$authorId		= $row['pt_create_user_id'];		// コンテンツ登録者
 			$authorName		= $row['lu_name'];				// コンテンツ登録者名
 			$authorUrl		= '';			// コンテンツ登録者URL
 			$date			= $row['pt_create_dt'];
-			$contentHtml	= $row['pt_description'];
+			$contentHtml	= $row['pt_html'];
 			$thumbSrc		= $row['pt_thumb_src'];	// サムネールの元のファイル(リソースディレクトリからの相対パス)
 			
 			// サムネールが設定されていない場合は、製品の各種画像を取得
@@ -673,6 +749,7 @@ class ContentApi extends BaseApi
 		$post->menu_order = 0;
 		// Magic3設定値追加
 		$post->post_title = $title;
+		$post->post_excerpt = $excerpt;			// 概要
 		$post->post_content = $contentHtml;
 		$post->guid = $this->getContentUrl($contentType, $id);	// 詳細画面URL
 		$post->filter = 'raw';
