@@ -103,6 +103,11 @@ class WC_Product extends WC_Abstract_Legacy_Product {
 	 */
 	protected $supports = array();
 
+	/**
+	 * Magic3追加分
+	 */
+	protected $taxType;				// 税タイプ(空の場合は課税なし)
+	 
 	/**
 	 * Get the product if ID is passed, otherwise the product is new and empty.
 	 * This class should NOT be instantiated, but the wc_get_product() function
@@ -121,11 +126,34 @@ class WC_Product extends WC_Abstract_Legacy_Product {
 		} else {
 			$this->set_object_read( true );
 		}
-/*
-		$this->data_store = WC_Data_Store::load( 'product-' . $this->get_type() );
-		if ( $this->get_id() > 0 ) {
-			$this->data_store->read( $this );
-		}*/
+		
+		// 商品情報取得
+		global $gContentApi;
+		$ret = $gContentApi->getProductInfo($product, $rowProduct, $rowPrice, $rowImage, $rowStatus, $rowCategory);
+		if ($ret){
+			// 価格
+			$priceInfo = $gContentApi->getProductPrice($rowPrice, 'regular');
+			$regularPrice = $priceInfo['pp_price'];	// 通常価格
+			$priceInfo = $gContentApi->getProductPrice($rowPrice, 'sale');
+			$salePrice = $priceInfo['pp_price'];	// セール価格
+			
+			$price = $regularPrice;
+			if (floatval($salePrice) > 0) $price = $salePrice;
+			$this->data['regular_price'] = $regularPrice;
+			$this->data['sale_price'] = $salePrice;
+			$this->data['price'] = $price;			// 実売価格
+			
+			// 税タイプ
+			$this->taxType = $gContentApi->getProductTaxType($rowProduct);
+			if (empty($this->taxType)) $this->data['tax_status'] = 'none';			// 課税タイプが設定されていない場合は課税処理しない
+			
+			// 商品の状態
+			if ($rowProduct['pt_visible'] && $rowProduct['pt_sell_status'] < 3/*未設定,カート可,販売中*/){
+				$this->data['status'] = 'publish';
+			} else {
+				$this->data['status'] = 'private';
+			}
+		}
 	}
 
 	/**
@@ -678,6 +706,18 @@ class WC_Product extends WC_Abstract_Legacy_Product {
 		return $this->get_prop( 'review_count', $context );
 	}
 
+	/**
+	 * Magic3追加分
+	 */
+	/**
+	 * 税タイプ取得
+	 *
+	 * @return string			税タイプ(空の場合は課税なし)
+	 */
+	public function getTaxType() {
+		return $this->taxType;
+	}
+	
 	/*
 	|--------------------------------------------------------------------------
 	| Setters
@@ -1650,11 +1690,11 @@ class WC_Product extends WC_Abstract_Legacy_Product {
 	 * @return string
 	 */
 	public function get_price_html( $deprecated = '' ) {
-		if ( '' === $this->get_price() ) {
+		if ( '' === $this->get_price() ) {		// 価格が設定されていない場合
 			$price = apply_filters( 'woocommerce_empty_price_html', '', $this );
-		} elseif ( $this->is_on_sale() ) {
+		} elseif ( $this->is_on_sale() ) {		// セール価格が設定されている場合
 			$price = wc_format_sale_price( wc_get_price_to_display( $this, array( 'price' => $this->get_regular_price() ) ), wc_get_price_to_display( $this ) ) . $this->get_price_suffix();
-		} else {
+		} else {		// 通常価格のみの場合
 			$price = wc_price( wc_get_price_to_display( $this ) ) . $this->get_price_suffix();
 		}
 
