@@ -1724,6 +1724,7 @@ class WP_Query {
 			$category = null;			// カテゴリー。設定なしの場合はnullを設定。
 		
 			// ページタイプごとの処理
+			// $this->is_singleの設定は前もってcontentApi側で行う
 			$pageType = $gContentApi->getPageType();		// ページタイプ取得
 			switch ($pageType){
 			case 'single':			// ブログ単体記事ページの場合
@@ -1869,13 +1870,29 @@ class WP_Query {
 //		$paged = $pageNo;				// グローバル変数へ代入
 //		if ($pageNo > 1) $this->is_paged = true;
 		
-		// 汎用コンテンツ以外のパターンは?
-		$value = absint($query['page_id']);			// 汎用コンテンツID
-		if ($value > 0){
-			$this->query_vars['page_id'] = $value;
+		// データタイプを取得
+		$postType = 'post';
+		$value = $query['post_type'];
+		if (!empty($value)) $postType = $value;
+		
+		if ($postType == 'post'){			// ブログコンテンツの場合
+		} else if ($postType == 'product'){			// 製品の場合
+			$itemCount = 0;		// 項目数デフォルト
+			$value = absint($query['posts_per_page']);			// 取得数
+			if ($value > 0) $itemCount = $value;
+		
+			$gContentApi->setCondition(array(), ''/*現在の言語*/, $itemCount/*最大取得数(デフォルト)*/, 1/*ページ番号*/,
+										''/*キーワード*/, null/*期間開始日時*/, null/*期間終了日時*/, null/*カテゴリー*/, M3_VIEW_TYPE_PRODUCT/*コンテンツタイプ*/);
+			$this->posts = $gContentApi->getContentList(M3_VIEW_TYPE_PRODUCT);		// コンテンツタイプは製品を指定
+		} else {
+			// 汎用コンテンツの場合
+			$value = absint($query['page_id']);			// 汎用コンテンツID
+			if ($value > 0){
+				$this->query_vars['page_id'] = $value;
 			
-			// 汎用コンテンツ取得
-			$this->posts = $gContentApi->getPageContentList($query);
+				// 汎用コンテンツ取得
+				$this->posts = $gContentApi->getPageContentList($query);
+			}
 		}
 
 		// Ensure that any posts added/modified via one of the filters above are
@@ -1888,7 +1905,8 @@ class WP_Query {
 			$this->post = reset( $this->posts );
 			
 			// the_post()の前にget_post()が呼ばれることがあるのでグローバル変数に保存
-//			$GLOBALS['post'] = $this->post;			// ########## 注意 ##### the_post()の実行前に初期値を設定しておくのがよいか実験中 ##### 注意 ##########
+			$GLOBALS['post'] = $this->post;			// ########## 注意 ##### the_post()の実行前に初期値を設定しておくのがよいか実験中 ##### 注意 ##########
+//			$GLOBALS['post_sub'] = $this->post;		// ########## サブループ用グローバルWP_Post型データ(Magic3で追加)                            ##########
 		} else {
 			$this->post_count = 0;
 			$this->posts = array();
@@ -1986,7 +2004,7 @@ class WP_Query {
 	 *
 	 * @global WP_Post $post
 	 */
-	/***** テンプレートのからループで毎回実行され、グローバルの$postが行進される *****/
+	/***** テンプレートのからループで毎回実行され、グローバルの$postが更新される *****/
 	public function the_post() {
 		global $post;
 		$this->in_the_loop = true;
@@ -2796,6 +2814,16 @@ class WP_Query {
 	 * @return bool Whether the query is for an existing single post of any of the given post types.
 	 */
 	public function is_singular( $post_types = '' ) {
+		//global $post;		// get_posts()が呼ばれていない、メインループに入っていない場合があるので使用不可
+		global $gContentApi;
+		
+		// データタイプが指定されている場合はWP_Postデータタイプもチェック
+		$postType = $gContentApi->getPostType();
+//		if (empty($post_types) || $post_types == $postType){
+		if (empty($post_types) || in_array($postType, (array)$post_types)){
+			return $this->is_single || $this->is_page || $this->is_attachment;
+		}
+		return false;
 /*		if ( empty( $post_types ) || !$this->is_singular )
 			return (bool) $this->is_singular;
 
@@ -2803,7 +2831,6 @@ class WP_Query {
 
 		return in_array( $post_obj->post_type, (array) $post_types );
 		*/
-		return $this->is_single || $this->is_page || $this->is_attachment;
 	}
 
 	/**
@@ -2976,7 +3003,8 @@ class WP_Query {
 		 * @param WP_Post  &$post The Post object (passed by reference).
 		 * @param WP_Query &$this The current Query object (passed by reference).
 		 */
-//		do_action_ref_array( 'the_post', array( &$post, &$this ) );
+		// ##### 製品情報(product)等の追加取得 #####
+		do_action_ref_array( 'the_post', array( &$post, &$this ) );
 
 		return true;
 	}
