@@ -21,11 +21,11 @@ foreach ( array( 'pre_term_name', 'pre_comment_author_name', 'pre_link_name', 'p
 
 // Strip, kses, special chars for string display
 foreach ( array( 'term_name', 'comment_author_name', 'link_name', 'link_target', 'link_rel', 'user_display_name', 'user_first_name', 'user_last_name', 'user_nickname' ) as $filter ) {
-	if ( is_admin() ) {
+/*	if ( is_admin() ) {
 		// These are expensive. Run only on admin pages for defense in depth.
 		add_filter( $filter, 'sanitize_text_field'  );
 		add_filter( $filter, 'wp_kses_data'       );
-	}
+	}*/
 	add_filter( $filter, '_wp_specialchars', 30 );
 }
 
@@ -35,12 +35,12 @@ foreach ( array( 'pre_term_description', 'pre_link_description', 'pre_link_notes
 }
 
 // Kses only for textarea admin displays
-if ( is_admin() ) {
+/*if ( is_admin() ) {
 	foreach ( array( 'term_description', 'link_description', 'link_notes', 'user_description' ) as $filter ) {
 		add_filter( $filter, 'wp_kses_data' );
 	}
 	add_filter( 'comment_text', 'wp_kses_post' );
-}
+}*/
 
 // Email saves
 foreach ( array( 'pre_comment_author_email', 'pre_user_email' ) as $filter ) {
@@ -52,25 +52,25 @@ foreach ( array( 'pre_comment_author_email', 'pre_user_email' ) as $filter ) {
 // Email admin display
 foreach ( array( 'comment_author_email', 'user_email' ) as $filter ) {
 	add_filter( $filter, 'sanitize_email' );
-	if ( is_admin() )
-		add_filter( $filter, 'wp_kses_data' );
+//	if ( is_admin() )
+//		add_filter( $filter, 'wp_kses_data' );
 }
 
 // Save URL
-foreach ( array( 'pre_comment_author_url', 'pre_user_url', 'pre_link_url', 'pre_link_image',
+/*foreach ( array( 'pre_comment_author_url', 'pre_user_url', 'pre_link_url', 'pre_link_image',
 	'pre_link_rss', 'pre_post_guid' ) as $filter ) {
 	add_filter( $filter, 'wp_strip_all_tags' );
 	add_filter( $filter, 'esc_url_raw'       );
 	add_filter( $filter, 'wp_filter_kses'    );
-}
+}*/
 
 // Display URL
 foreach ( array( 'user_url', 'link_url', 'link_image', 'link_rss', 'comment_url', 'post_guid' ) as $filter ) {
-	if ( is_admin() )
-		add_filter( $filter, 'wp_strip_all_tags' );
+//	if ( is_admin() )
+//		add_filter( $filter, 'wp_strip_all_tags' );
 	add_filter( $filter, 'esc_url'           );
-	if ( is_admin() )
-		add_filter( $filter, 'wp_kses_data'    );
+//	if ( is_admin() )
+//		add_filter( $filter, 'wp_kses_data'    );
 }
 
 // Slugs
@@ -122,11 +122,11 @@ foreach ( array( 'term_description' ) as $filter ) {
 }
 
 // Format for RSS
-add_filter( 'term_name_rss', 'convert_chars' );
+//add_filter( 'term_name_rss', 'convert_chars' );
 
 // Pre save hierarchy
-add_filter( 'wp_insert_post_parent', 'wp_check_post_hierarchy_for_loops', 10, 2 );
-add_filter( 'wp_update_term_parent', 'wp_check_term_hierarchy_for_loops', 10, 3 );
+//add_filter( 'wp_insert_post_parent', 'wp_check_post_hierarchy_for_loops', 10, 2 );
+//add_filter( 'wp_update_term_parent', 'wp_check_term_hierarchy_for_loops', 10, 3 );
 
 // Display filters
 add_filter( 'the_title', 'wptexturize'   );
@@ -169,29 +169,29 @@ add_filter( 'widget_text', 'balanceTags' );
 add_filter( 'date_i18n', 'wp_maybe_decline_date' );
 
 // RSS filters
-add_filter( 'the_title_rss',      'strip_tags'                    );
-add_filter( 'the_title_rss',      'ent2ncr',                    8 );
-add_filter( 'the_title_rss',      'esc_html'                      );
-add_filter( 'the_content_rss',    'ent2ncr',                    8 );
-add_filter( 'the_content_feed',   'wp_staticize_emoji'            );
-add_filter( 'the_content_feed',   '_oembed_filter_feed_content'   );
-add_filter( 'the_excerpt_rss',    'convert_chars'                 );
-add_filter( 'the_excerpt_rss',    'ent2ncr',                    8 );
-add_filter( 'comment_author_rss', 'ent2ncr',                    8 );
-add_filter( 'comment_text_rss',   'ent2ncr',                    8 );
-add_filter( 'comment_text_rss',   'esc_html'                      );
-add_filter( 'comment_text_rss',   'wp_staticize_emoji'            );
-add_filter( 'bloginfo_rss',       'ent2ncr',                    8 );
-add_filter( 'the_author',         'ent2ncr',                    8 );
-add_filter( 'the_guid',           'esc_url'                       );
+//add_filter( 'the_title_rss',      'strip_tags'                    );
+//add_filter( 'the_title_rss',      'ent2ncr',                    8 );
+//add_filter( 'the_title_rss',      'esc_html'                      );
+//add_filter( 'the_content_rss',    'ent2ncr',                    8 );
+//add_filter( 'the_content_feed',   'wp_staticize_emoji'            );
+//add_filter( 'the_content_feed',   '_oembed_filter_feed_content'   );
+//add_filter( 'the_excerpt_rss',    'convert_chars'                 );
+//add_filter( 'the_excerpt_rss',    'ent2ncr',                    8 );
+//add_filter( 'comment_author_rss', 'ent2ncr',                    8 );
+//add_filter( 'comment_text_rss',   'ent2ncr',                    8 );
+//add_filter( 'comment_text_rss',   'esc_html'                      );
+//add_filter( 'comment_text_rss',   'wp_staticize_emoji'            );
+//add_filter( 'bloginfo_rss',       'ent2ncr',                    8 );
+//add_filter( 'the_author',         'ent2ncr',                    8 );
+//add_filter( 'the_guid',           'esc_url'                       );
 
 // Email filters
-add_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
+//add_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
 
 // Mark site as no longer fresh
-foreach ( array( 'publish_post', 'publish_page', 'wp_ajax_save-widget', 'wp_ajax_widgets-order', 'customize_save_after' ) as $action ) {
+/*foreach ( array( 'publish_post', 'publish_page', 'wp_ajax_save-widget', 'wp_ajax_widgets-order', 'customize_save_after' ) as $action ) {
 	add_action( $action, '_delete_option_fresh_site' );
-}
+}*/
 
 // Misc filters
 add_filter( 'option_ping_sites',        'privacy_ping_filter'                 );
@@ -199,8 +199,8 @@ add_filter( 'option_blog_charset',      '_wp_specialchars'                    );
 add_filter( 'option_blog_charset',      '_canonical_charset'                  );
 add_filter( 'option_home',              '_config_wp_home'                     );
 add_filter( 'option_siteurl',           '_config_wp_siteurl'                  );
-add_filter( 'tiny_mce_before_init',     '_mce_set_direction'                  );
-add_filter( 'teeny_mce_before_init',    '_mce_set_direction'                  );
+//add_filter( 'tiny_mce_before_init',     '_mce_set_direction'                  );
+//add_filter( 'teeny_mce_before_init',    '_mce_set_direction'                  );
 add_filter( 'pre_kses',                 'wp_pre_kses_less_than'               );
 add_filter( 'sanitize_title',           'sanitize_title_with_dashes',   10, 3 );
 add_action( 'check_comment_flood',      'check_comment_flood_db',       10, 4 );
@@ -214,9 +214,9 @@ add_filter( 'option_category_base',     '_wp_filter_taxonomy_base'            );
 //add_filter( 'pings_open',               '_close_comments_for_old_post', 10, 2 );
 add_filter( 'editable_slug',            'urldecode'                           );
 add_filter( 'editable_slug',            'esc_textarea'                        );
-add_filter( 'nav_menu_meta_box_object', '_wp_nav_menu_meta_box_object'        );
-add_filter( 'pingback_ping_source_uri', 'pingback_ping_source_uri'            );
-add_filter( 'xmlrpc_pingback_error',    'xmlrpc_pingback_error'               );
+//add_filter( 'nav_menu_meta_box_object', '_wp_nav_menu_meta_box_object'        );
+//add_filter( 'pingback_ping_source_uri', 'pingback_ping_source_uri'            );
+//add_filter( 'xmlrpc_pingback_error',    'xmlrpc_pingback_error'               );
 add_filter( 'title_save_pre',           'trim'                                );
 
 add_action( 'transition_comment_status', '_clear_modified_cache_on_transition_comment_status', 10, 2 );
@@ -246,9 +246,9 @@ add_action( 'wp_head',             'adjacent_posts_rel_link_wp_head', 10, 0 );
 add_action( 'wp_head',             'locale_stylesheet'                      );
 add_action( 'publish_future_post', 'check_and_publish_future_post',   10, 1 );
 add_action( 'wp_head',             'noindex',                          1    );
-add_action( 'wp_head',             'print_emoji_detection_script',     7    );
-add_action( 'wp_head',             'wp_print_styles',                  8    );
-add_action( 'wp_head',             'wp_print_head_scripts',            9    );
+//add_action( 'wp_head',             'print_emoji_detection_script',     7    );
+add_action( 'wp_head',             'wp_print_styles',                  8    );			// ヘッダ部でWordPressスタイルシート読み込み
+add_action( 'wp_head',             'wp_print_head_scripts',            9    );			// ヘッダ部でWordPressJavascriptファイル読み込み
 add_action( 'wp_head',             'wp_generator'                           );			// Magic3ヘッダ出力
 add_action( 'wp_head',             'rel_canonical'                          );
 add_action( 'wp_head',             'wp_shortlink_wp_head',            10, 0 );
@@ -259,23 +259,23 @@ add_action( 'template_redirect',   'wp_shortlink_header',             11, 0 );
 add_action( 'wp_print_footer_scripts', '_wp_footer_scripts'                 );
 //add_action( 'init',                'check_theme_switched',            99    );
 //add_action( 'after_switch_theme',  '_wp_sidebars_changed'                   );
-add_action( 'wp_print_styles',     'print_emoji_styles'                     );
+//add_action( 'wp_print_styles',     'print_emoji_styles'                     );
 
 if ( isset( $_GET['replytocom'] ) )
     add_action( 'wp_head', 'wp_no_robots' );
 
 // Login actions
-add_filter( 'login_head',          'wp_resource_hints',             8     );
-add_action( 'login_head',          'wp_print_head_scripts',         9     );
-add_action( 'login_head',          'print_admin_styles',            9     );
-add_action( 'login_head',          'wp_site_icon',                  99    );
-add_action( 'login_footer',        'wp_print_footer_scripts',       20    );
-add_action( 'login_init',          'send_frame_options_header',     10, 0 );
+//add_filter( 'login_head',          'wp_resource_hints',             8     );
+//add_action( 'login_head',          'wp_print_head_scripts',         9     );
+//add_action( 'login_head',          'print_admin_styles',            9     );
+//add_action( 'login_head',          'wp_site_icon',                  99    );
+//add_action( 'login_footer',        'wp_print_footer_scripts',       20    );
+//add_action( 'login_init',          'send_frame_options_header',     10, 0 );
 
 // Feed Generator Tags
-foreach ( array( 'rss2_head', 'commentsrss2_head', 'rss_head', 'rdf_header', 'atom_head', 'comments_atom_head', 'opml_head', 'app_head' ) as $action ) {
+/*foreach ( array( 'rss2_head', 'commentsrss2_head', 'rss_head', 'rdf_header', 'atom_head', 'comments_atom_head', 'opml_head', 'app_head' ) as $action ) {
 	add_action( $action, 'the_generator' );
-}
+}*/
 
 // Feed Site Icon
 //add_action( 'atom_head', 'atom_site_icon' );
@@ -283,8 +283,8 @@ foreach ( array( 'rss2_head', 'commentsrss2_head', 'rss_head', 'rdf_header', 'at
 
 
 // WP Cron
-if ( !defined( 'DOING_CRON' ) )
-	add_action( 'init', 'wp_cron' );
+//if ( !defined( 'DOING_CRON' ) )
+//	add_action( 'init', 'wp_cron' );
 
 // 2 Actions 2 Furious
 //add_action( 'do_feed_rdf',                'do_feed_rdf',                             10, 1 );
@@ -300,31 +300,31 @@ add_action( 'sanitize_comment_cookies',   'sanitize_comment_cookies'
 //add_action( 'admin_print_footer_scripts', '_wp_footer_scripts'                             );
 //add_action( 'admin_print_styles',         'print_emoji_styles'                             );
 //add_action( 'admin_print_styles',         'print_admin_styles',                      20    );
-add_action( 'init',                       'smilies_init',                             5    );
+//add_action( 'init',                       'smilies_init',                             5    );
 //add_action( 'plugins_loaded',             'wp_maybe_load_widgets',                    0    );
 add_action( 'plugins_loaded',             'wp_maybe_load_embeds',                     0    );
 //add_action( 'shutdown',                   'wp_ob_end_flush_all',                      1    );
 // Create a revision whenever a post is updated.
 //add_action( 'post_updated',               'wp_save_post_revision',                   10, 1 );
-add_action( 'publish_post',               '_publish_post_hook',                       5, 1 );
-add_action( 'transition_post_status',     '_transition_post_status',                  5, 3 );
-add_action( 'transition_post_status',     '_update_term_count_on_transition_post_status', 10, 3 );
+//add_action( 'publish_post',               '_publish_post_hook',                       5, 1 );
+//add_action( 'transition_post_status',     '_transition_post_status',                  5, 3 );
+//add_action( 'transition_post_status',     '_update_term_count_on_transition_post_status', 10, 3 );
 add_action( 'comment_form',               'wp_comment_form_unfiltered_html_nonce'          );
 //add_action( 'wp_scheduled_delete',        'wp_scheduled_delete'                            );
-add_action( 'wp_scheduled_auto_draft_delete', 'wp_delete_auto_drafts'                      );
+//add_action( 'wp_scheduled_auto_draft_delete', 'wp_delete_auto_drafts'                      );
 //add_action( 'admin_init',                 'send_frame_options_header',               10, 0 );
-add_action( 'importer_scheduled_cleanup', 'wp_delete_attachment'                           );
-add_action( 'upgrader_scheduled_cleanup', 'wp_delete_attachment'                           );
+//add_action( 'importer_scheduled_cleanup', 'wp_delete_attachment'                           );
+//add_action( 'upgrader_scheduled_cleanup', 'wp_delete_attachment'                           );
 add_action( 'welcome_panel',              'wp_welcome_panel'                               );
 
 // Navigation menu actions
-add_action( 'delete_post',                '_wp_delete_post_menu_item'         );
-add_action( 'delete_term',                '_wp_delete_tax_menu_item',   10, 3 );
-add_action( 'transition_post_status',     '_wp_auto_add_pages_to_menu', 10, 3 );
+//add_action( 'delete_post',                '_wp_delete_post_menu_item'         );
+//add_action( 'delete_term',                '_wp_delete_tax_menu_item',   10, 3 );
+//add_action( 'transition_post_status',     '_wp_auto_add_pages_to_menu', 10, 3 );
 
 // Post Thumbnail CSS class filtering
-add_action( 'begin_fetch_post_thumbnail_html', '_wp_post_thumbnail_class_filter_add'    );
-add_action( 'end_fetch_post_thumbnail_html',   '_wp_post_thumbnail_class_filter_remove' );
+//add_action( 'begin_fetch_post_thumbnail_html', '_wp_post_thumbnail_class_filter_add'    );
+//add_action( 'end_fetch_post_thumbnail_html',   '_wp_post_thumbnail_class_filter_remove' );
 
 // Redirect Old Slugs
 //add_action( 'template_redirect',  'wp_old_slug_redirect'              );
@@ -332,10 +332,10 @@ add_action( 'end_fetch_post_thumbnail_html',   '_wp_post_thumbnail_class_filter_
 //add_action( 'attachment_updated', 'wp_check_for_changed_slugs', 12, 3 );
 
 // Nonce check for Post Previews
-add_action( 'init', '_show_post_preview' );
+//add_action( 'init', '_show_post_preview' );
 
 // Output JS to reset window.name for previews
-add_action( 'wp_head', 'wp_post_preview_js', 1 );
+//add_action( 'wp_head', 'wp_post_preview_js', 1 );
 
 // Timezone
 add_filter( 'pre_option_gmt_offset','wp_timezone_override_offset' );
@@ -393,25 +393,25 @@ add_action( 'edit_user_created_user', 'wp_send_new_user_notifications', 10, 2 );
 add_action( 'wp_loaded', '_custom_header_background_just_in_time' );
 add_action( 'wp_head', '_custom_logo_header_styles' );
 add_action( 'plugins_loaded', '_wp_customize_include' );
-add_action( 'transition_post_status', '_wp_customize_publish_changeset', 10, 3 );
+add_action( 'transition_post_status', '_wp_customize_publish_changeset', 10, 3 );		// テンプレートカスタマイズを反映
 //add_action( 'admin_enqueue_scripts', '_wp_customize_loader_settings' );
 add_action( 'delete_attachment', '_delete_attachment_theme_mod' );
 
 // Calendar widget cache
-add_action( 'save_post', 'delete_get_calendar_cache' );
-add_action( 'delete_post', 'delete_get_calendar_cache' );
-add_action( 'update_option_start_of_week', 'delete_get_calendar_cache' );
-add_action( 'update_option_gmt_offset', 'delete_get_calendar_cache' );
+//add_action( 'save_post', 'delete_get_calendar_cache' );
+//add_action( 'delete_post', 'delete_get_calendar_cache' );
+//add_action( 'update_option_start_of_week', 'delete_get_calendar_cache' );
+//add_action( 'update_option_gmt_offset', 'delete_get_calendar_cache' );
 
 // Author
-add_action( 'transition_post_status', '__clear_multi_author_cache' );
+//add_action( 'transition_post_status', '__clear_multi_author_cache' );
 
 // Post
-add_action( 'init', 'create_initial_post_types', 0 ); // highest priority
-add_action( 'admin_menu', '_add_post_type_submenus' );
-add_action( 'before_delete_post', '_reset_front_page_settings_for_post' );
-add_action( 'wp_trash_post',      '_reset_front_page_settings_for_post' );
-add_action( 'change_locale', 'create_initial_post_types' );
+//add_action( 'init', 'create_initial_post_types', 0 ); // highest priority
+//add_action( 'admin_menu', '_add_post_type_submenus' );
+//add_action( 'before_delete_post', '_reset_front_page_settings_for_post' );
+//add_action( 'wp_trash_post',      '_reset_front_page_settings_for_post' );
+//add_action( 'change_locale', 'create_initial_post_types' );
 
 // Post Formats
 add_filter( 'request', '_post_format_request' );
@@ -421,8 +421,8 @@ add_filter( 'get_terms', '_post_format_get_terms', 10, 3 );
 add_filter( 'wp_get_object_terms', '_post_format_wp_get_object_terms' );
 
 // KSES
-add_action( 'init', 'kses_init' );
-add_action( 'set_current_user', 'kses_init' );
+//add_action( 'init', 'kses_init' );
+//add_action( 'set_current_user', 'kses_init' );
 
 // Script Loader
 add_action( 'wp_default_scripts', 'wp_default_scripts' );
@@ -436,8 +436,8 @@ add_action( 'wp_default_styles', 'wp_default_styles' );
 add_filter( 'style_loader_src', 'wp_style_loader_src', 10, 2 );
 
 // Taxonomy
-add_action( 'init', 'create_initial_taxonomies', 0 ); // highest priority
-add_action( 'change_locale', 'create_initial_taxonomies' );
+//add_action( 'init', 'create_initial_taxonomies', 0 ); // highest priority
+//add_action( 'change_locale', 'create_initial_taxonomies' );
 
 // Canonical
 add_action( 'template_redirect', 'redirect_canonical' );
@@ -451,10 +451,10 @@ add_action( 'wp_playlist_scripts', 'wp_playlist_scripts' );
 add_action( 'customize_controls_enqueue_scripts', 'wp_plupload_default_settings' );
 
 // Nav menu
-add_filter( 'nav_menu_item_id', '_nav_menu_item_id_use_once', 10, 2 );
+//add_filter( 'nav_menu_item_id', '_nav_menu_item_id_use_once', 10, 2 );
 
 // Widgets
-add_action( 'init', 'wp_widgets_init', 1 );
+add_action( 'init', 'wp_widgets_init', 1 );		// ウィジェットのCSSの初期化等
 
 // Admin Bar
 // Don't remove. Wrong way to disable.
@@ -478,7 +478,7 @@ add_filter( 'media_send_to_editor', 'image_media_send_to_editor', 10, 3 );
 //add_action( 'wp_head',                'wp_oembed_add_host_js'                 );
 
 add_action( 'embed_head',             'enqueue_embed_scripts',           1    );
-add_action( 'embed_head',             'print_emoji_detection_script'          );
+//add_action( 'embed_head',             'print_emoji_detection_script'          );
 add_action( 'embed_head',             'print_embed_styles'                    );
 add_action( 'embed_head',             'wp_print_head_scripts',          20    );
 add_action( 'embed_head',             'wp_print_styles',                20    );
