@@ -317,7 +317,7 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		}
 		
 		// メニューID選択メニュー作成
-		$this->db->getMenuIdList(array($this, 'menuIdListLoop'));
+		$this->db->getMenuIdList(-1/*すべてのアクセスポイントが対象*/, array($this, 'menuIdListLoop'), false/*ウィジェット専用のメニューは取得しない*/, true/*有効なアクセスポイントのみ取得*/);
 		
 		// メニューツリー作成
 		$treeMenu = $this->createTreeMenu($this->menuId, 0);
