@@ -8,9 +8,9 @@
  *
  * @package    パンくずリスト
  * @author     株式会社 毎日メディアサービス
- * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
+ * @copyright  Copyright 2010-2015 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: breadcrumbWidgetContainer.php 4936 2012-06-05 09:43:49Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -19,7 +19,6 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/breadcrumbDb.php');
 class breadcrumbWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;	// DB接続オブジェクト
 	private $currentMacroUrl;		// 現在のマクロ表記URL
 	private $menuItems;		// メニュー項目情報
 	private $iconTag;		// パンくずリストのアイコン
@@ -28,8 +27,7 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 	const DEFAULT_HOME_URL = '/';				// デフォルトのホームURL
 	const MAX_MENU_TREE_LEVEL = 5;			// メニュー階層最大数
 	const MENU_ITEM_NONAME = '名称未設定';	// メニュー項目に名前が設定されていない場合の名前
-	const ARROW_IMAGE_FILE = '/images/arrow.png';		// パンくずリスト用画像
-	const TEMPLATE_ARROW_IMAGE_FILE = '/images/arrow.png';		// パンくずリスト用画像(テンプレート内)
+	const DEFAULT_ARROW_IMAGE_FILE = '/images/arrow.png';		// パンくずリスト用画像
 	
 	/**
 	 * コンストラクタ
@@ -76,26 +74,30 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 		// 表示設定を取得
 		$visibleOnRoot = 1;				// トップページでリスト表示するかどうか
 		$useHiddenMenu = 0;		// 非表示のメニューウィジェットの定義を使用する
+		$separatorImgPath = '';		// 区切り画像パス
 		$paramObj = $this->getWidgetParamObj();
 		if (!empty($paramObj)){
 			$visibleOnRoot	= $paramObj->visibleOnRoot;
 			if (isset($paramObj->useHiddenMenu)) $useHiddenMenu = $paramObj->useHiddenMenu;		// 非表示のメニューウィジェットの定義を使用する
+			$separatorImgPath = $paramObj->separatorImgPath;		// 区切り画像パス
 		}
 		
 		// 現在表示中のメニューID取得
 		$ret = $this->db->getMenuId($useHiddenMenu, $this->gEnv->getCurrentPageId(), $this->gEnv->getCurrentPageSubId(), $allMenu);
 		if (!$ret) return;
 		
-		// パンくずリスト用アイコンを取得
-		$iconUrl = '';
-		$iconPath = $this->gEnv->getCurrentTemplatePath() . self::TEMPLATE_ARROW_IMAGE_FILE;
-		if (file_exists($iconPath)) $iconUrl = $this->gEnv->getCurrentTemplateUrl() . self::TEMPLATE_ARROW_IMAGE_FILE;
-		
-		// テンプレートのアイコンがないときは、デフォルトのアイコンを使用
-		if (empty($iconUrl)){
-			$iconUrl = $this->gEnv->getCurrentWidgetRootUrl() . self::TEMPLATE_ARROW_IMAGE_FILE;
+		// 区切り画像
+		if (empty($separatorImgPath)){
+			$separatorImgUrl = $this->gEnv->getCurrentWidgetRootUrl() . self::DEFAULT_ARROW_IMAGE_FILE;		// デフォルトの画像
+		} else {
+//			$separatorImgUrl = $this->gEnv->getRootUrl() . $separatorImgPath;		// ユーザ指定の画像
+			$separatorImgUrl = $this->gEnv->getResourceUrl() . $separatorImgPath;		// ユーザ指定の画像
+		}
+		if ($this->_renderType == M3_RENDER_BOOTSTRAP){			// Bootstrap型テンプレートの場合は区切りアイコンなし
+			$this->iconTag = '';
+		} else {
+			$this->iconTag = ' <img src="' . $this->getUrl($separatorImgUrl) . '" /> ';		// 両端にスペースを入れる
 		}
-		$this->iconTag = ' <img src="' . $this->getUrl($iconUrl) . '" /> ';		// 両端にスペースを入れる
 	
 		// 重複しないメニューIDを作成
 		$menuIdArray = array();
@@ -122,7 +124,8 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 		$this->currentMacroUrl = $this->gEnv->getMacroPath($currentUrl);
 		if ($this->isRootUrl($this->currentMacroUrl)){// ルート位置の場合の処理
 			if ($visibleOnRoot){		// ルートのときリスト表示するとき
-				$html = '<span class="breadcrumbs pathway">' . $this->convertToDispString($homeName) . '</span>';
+				//$html = '<span class="breadcrumbs pathway">' . $this->convertToDispString($homeName) . '</span>';
+				$html = $this->_createLinkOuter($this->convertToDispString($homeName));
 				$this->tmpl->addVar("_widget", "link", $html);
 			}
 			return;
@@ -148,7 +151,8 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 			$pageSubId = $this->gEnv->getCurrentPageSubId();
 			if (count($this->currentQueryArray) == 1 && $this->currentQueryArray[M3_REQUEST_PARAM_PAGE_SUB_ID] == $this->gEnv->getDefaultPageSubId()){
 				if ($visibleOnRoot){		// ルートのときリスト表示するとき
-					$html = '<span class="breadcrumbs pathway">' . $this->convertToDispString($homeName) . '</span>';
+					//$html = '<span class="breadcrumbs pathway">' . $this->convertToDispString($homeName) . '</span>';
+					$html = $this->_createLinkOuter($this->convertToDispString($homeName));
 					$this->tmpl->addVar("_widget", "link", $html);
 					return;
 				}
@@ -165,19 +169,18 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 
 				// ページサブID以外のパラメータをもつ場合のみリンクを作成
 				if (count($this->currentQueryArray) == 1 && isset($this->currentQueryArray[M3_REQUEST_PARAM_PAGE_SUB_ID])){		
-					$html = $this->convertToDispString($pageName);
+					//$html = $this->convertToDispString($pageName);
+					$html = $this->_createLink($pageName);
 				} else {
 					$pageUrl = $this->gEnv->createCurrentPageUrl();
 					$linkUrl = $this->getUrl($pageUrl, true/*リンク用*/);
-					$html = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($pageName) . '</a>';
+					//$html = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($pageName) . '</a>';
+					$html = $this->_createLink($pageName, $linkUrl);
 					
-					// getHeadSubTitle()はバージョン1.10.9以降利用可能
-					if (version_compare(M3_SYSTEM_VERSION, '1.10.9') >= 0){
-						// コンテンツ名が設定されている場合は出力
-						$titleArray = $this->gPage->getHeadSubTitle();
-						if (count($titleArray) > 0){
-							$html .= $this->createTitleLink($titleArray);
-						}
+					// コンテンツ名が設定されている場合は出力
+					$titleArray = $this->gPage->getHeadSubTitle();
+					if (count($titleArray) > 0){
+						$html .= $this->createTitleLink($titleArray);
 					}
 				}
 			}
@@ -230,8 +233,11 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 		}
 		if (!empty($html)){		// リンクが空のときは表示しない
 			$linkUrl = $this->getUrl($homeUrl, true/*リンク用*/);
-			$html = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($homeName) . '</a>' . $this->iconTag . $html;// リンクの間にアイコンを挿入
-			$html = '<span class="breadcrumbs pathway">' . $html . '</span>';
+			//$html = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($homeName) . '</a>' . $this->iconTag . $html;// リンクの間にアイコンを挿入
+			$html = $this->_createLink($homeName, $linkUrl) . $this->iconTag . $html;// リンクの間にアイコンを挿入
+			
+			//$html = '<span class="breadcrumbs pathway">' . $html . '</span>';
+			$html = $this->_createLinkOuter($html);
 			$this->tmpl->addVar("_widget", "link", $html);
 		}
 	}
@@ -301,9 +307,11 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 			if ($i > 0) $outputHtml .= $this->iconTag;
 			
 			if (empty($linkUrl) || $i == $linkCount -1){		// 最後の項目はリンク作成しない
-				$outputHtml .= $this->convertToDispString($name) . M3_NL;
+				//$outputHtml .= $this->convertToDispString($name) . M3_NL;
+				$outputHtml .= $this->_createLink($name);
 			} else {
-				$outputHtml .= '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($name) . '</a>' . M3_NL;
+				//$outputHtml .= '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($name) . '</a>' . M3_NL;
+				$outputHtml .= $this->_createLink($name, $linkUrl);
 			}
 		}
 		return $outputHtml;
@@ -333,9 +341,11 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 			$outputHtml .= $this->iconTag;
 			
 			if (empty($linkUrl) || $i == $linkCount -1){		// 最後の項目はリンク作成しない
-				$outputHtml .= $this->convertToDispString($name) . M3_NL;
+				//$outputHtml .= $this->convertToDispString($name) . M3_NL;
+				$outputHtml .= $this->_createLink($name);
 			} else {
-				$outputHtml .= '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($name) . '</a>' . M3_NL;
+				//$outputHtml .= '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="pathway">' . $this->convertToDispString($name) . '</a>' . M3_NL;
+				$outputHtml .= $this->_createLink($name, $linkUrl);
 			}
 		}
 		return $outputHtml;
@@ -408,5 +418,49 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 		}
 		return false;
 	}
+	/**
+	 * リンク作成
+	 *
+	 * @param string  $name		タイトル
+	 * @param string  $url		リンク先URL。空の場合はリンクなし。
+	 * @return string			タグ
+	 */
+	function _createLink($name, $url = '')
+	{
+		$isNoLink = empty($url);		// リンクなし項目かどうか
+		$linkItem = '';
+		$listAttr = '';		// リストタグの属性
+		$linkAttr = '';		// リンクタグの属性
+		if ($this->_renderType == M3_RENDER_BOOTSTRAP){
+			if ($isNoLink){		// リンクなし項目の場合
+				$linkItem = '<li' . $listAttr .'>' . $this->convertToDispString($name) . '</li>';
+			} else {
+				$listAttr = ' class="active"';
+				$linkItem = '<li' . $listAttr .'><a href="' . $this->convertUrlToHtmlEntity($url) . '"' . $linkAttr . '>' . $this->convertToDispString($name) . '</a></li>';
+			}
+		} else {
+			if ($isNoLink){		// リンクなし項目の場合
+				$linkItem = $this->convertToDispString($name);
+			} else {
+				$linkAttr = ' class="pathway"';
+				$linkItem = '<a href="' . $this->convertUrlToHtmlEntity($url) . '"' . $linkAttr . '>' . $this->convertToDispString($name) . '</a>';
+			}
+		}
+		return $linkItem;
+	}
+	/**
+	 * リンクアウター作成
+	 *
+	 * @param string  $innerTags	リンク項目のタグ
+	 * @return string				タグ
+	 */
+	function _createLinkOuter($innerTags)
+	{
+		if ($this->_renderType == M3_RENDER_BOOTSTRAP){
+			return '<ol class="breadcrumb">' . $innerTags . '</ol>';
+		} else {
+			return '<span class="breadcrumbs pathway">' . $innerTags . '</span>';
+		}
+	}
 }
 ?>
