@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_dispProductWidgetContainer.php 5559 2013-01-16 13:09:11Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -21,6 +21,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
 	private $langId;		// 現在の言語ID
+	private $currencyId;	// 現在の通貨ID
 	private $viewStyle;		// 表示スタイル
 	private $categoryId;		// カテゴリーID
 	private $productId;			// 製品ID
@@ -39,7 +40,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 	private $headKeyword;	// METAタグキーワード
 	private $categoryTitleSeparator;	// カテゴリータイトル作成用セパレータ
 	const PRICE_OBJ_ID = "eclib";		// 価格計算オブジェクトID
-	const STANDARD_PRICE = 'selling';		// 通常価格
+	const REGULAR_PRICE = 'regular';		// 通常価格
 	const PRODUCT_IMAGE_MEDIUM = 'standard-product';		// 中サイズ商品画像ID
 	const PRODUCT_IMAGE_SMALL = 'small-product';		// 小サイズ商品画像ID
 	const PRODUCT_IMAGE_LARGE = 'large-product';		// 大サイズ商品画像ID
@@ -79,6 +80,8 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 		
 		// 価格計算用オブジェクト取得
 		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
+		
+		$this->currencyId = $this->ecObj->getDefaultCurrency();		// 現在の通貨ID
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -223,14 +226,14 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				$ret = $this->db->getProductByProductId($this->productId, $this->langId, $row, $row2, $row3, $row4, $row5);
 				if ($ret){
 					// 価格を取得
-					$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
+					$priceArray = $this->getPrice($row2, self::REGULAR_PRICE);
 					$price = $priceArray['pp_price'];	// 価格
 					$currency = $priceArray['pp_currency_id'];	// 通貨
 					$taxType = $row['pt_tax_type_id'];					// 税種別			
 
 					// 価格作成
 					$this->ecObj->setCurrencyType($currency, $this->langId);		// 通貨設定
-					$this->ecObj->setTaxType($taxType, $this->langId);		// 税種別設定
+					$this->ecObj->setTaxType($taxType);		// 税種別設定
 					$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 				} else {		// 商品情報が取得できないときは、カートの商品をキャンセル
 					$isValidItem = false;
@@ -411,18 +414,18 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 					$unitType = $unitRow['ut_symbol'];
 				}
 				$unitQuantity = $row['pt_unit_quantity'];		// 数量
-				$description = $row['pt_description'];			// 説明
-				$description_short = $row['pt_description_short'];		// 簡易説明
+				$description = $row['pt_html'];			// 説明
+				$description_short = $row['pt_description'];		// 簡易説明
 				//$keyword = $row['pt_search_keyword'];					// 検索キーワード
 				$this->headTitle = $row['pt_name'];		// METAタグタイトル
-				$this->headDesc = $row['pt_description_short'];		// METAタグ要約
+				$this->headDesc = $row['pt_description'];		// METAタグ要約
 				$this->headKeyword = $row['pt_meta_keywords'];			// METAタグキーワード
 				$url = $row['pt_site_url'];							// 詳細情報URL
 				$this->taxType = $row['pt_tax_type_id'];					// 税種別
 				//$adminNote = $row['pt_admin_note'];		// 管理者用備考
 			
 				// 価格を取得
-				$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
+				$priceArray = $this->getPrice($row2, self::REGULAR_PRICE);
 				$price = $priceArray['pp_price'];	// 価格
 				$currency = $priceArray['pp_currency_id'];	// 通貨
 				$taxType = $row['pt_tax_type_id'];					// 税種別
@@ -432,7 +435,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 			
 				// 表示額作成
 				$this->ecObj->setCurrencyType($currency, $lang);		// 通貨設定
-				$this->ecObj->setTaxType($taxType, $lang);		// 税種別設定
+				$this->ecObj->setTaxType($taxType);		// 税種別設定
 				$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 			
 				// 画像を取得
@@ -490,8 +493,8 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				$this->tmpl->addVar("_widget", "id", $row['pt_id']);		// 商品ID
 				$this->tmpl->addVar("_widget", "name", $row['pt_name']);		// 名前
 				$this->tmpl->addVar("_widget", "code", $row['pt_code']);		// 商品コード
-				$this->tmpl->addVar("_widget", "description", $row['pt_description']);		// 説明
-				$this->tmpl->addVar("_widget", "desc_short", $row['pt_description_short']);		// 簡易説明		
+				$this->tmpl->addVar("_widget", "description", $row['pt_html']);		// 説明
+				$this->tmpl->addVar("_widget", "desc_short", $row['pt_description']);		// 簡易説明		
 				$this->tmpl->addVar("show_cart", "unit_type", $unitType);		// 単位タイプ
 				$this->tmpl->addVar("show_cart", "quantity", '1');		// 数量デフォルト値
 				
@@ -572,7 +575,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 		$ret = $this->db->getProductBySerial($fetchedRow['pt_serial'], $row, $row2, $row3, $row4);
 		if ($ret){	
 			// 価格を取得
-			$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
+			$priceArray = $this->getPrice($row2, self::REGULAR_PRICE);
 			$price = $priceArray['pp_price'];	// 価格
 			$currency = $priceArray['pp_currency_id'];	// 通貨
 			$taxType = $row['pt_tax_type_id'];					// 税種別
@@ -582,7 +585,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 
 			// 表示額作成
 			$this->ecObj->setCurrencyType($currency, $lang);		// 通貨設定
-			$this->ecObj->setTaxType($taxType, $lang);		// 税種別設定
+			$this->ecObj->setTaxType($taxType);		// 税種別設定
 			$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 			
 			// 画像を取得
@@ -685,7 +688,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 			'name' => $this->convertToDispString($row['pt_name']),		// 名前
 			'code' => $this->convertToDispString($row['pt_code']),		// 商品コード
 			'disp_total_price' => $prePrice . $dispPrice . $postPrice,				// 税込み価格
-			'description_short' => $row['pt_description_short'],				// 簡易説明
+			'description_short' => $row['pt_description'],				// 簡易説明
 			'product_link' => $link												// 商品詳細リンク
 		);
 		$this->tmpl->addVars('productlist', $itemRow);
@@ -707,7 +710,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 	function getPrice($srcRows, $priceType)
 	{
 		for ($i = 0; $i < count($srcRows); $i++){
-			if ($srcRows[$i]['pp_price_type_id'] == $priceType){
+			if ($srcRows[$i]['pp_currency_id'] == $this->currencyId && $srcRows[$i]['pp_price_type_id'] == $priceType){
 				return $srcRows[$i];
 			}
 		}
