@@ -38,7 +38,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	private $contentIdArray;		// コンテンツID
 	private $cancelStock;		// 在庫キャンセル処理を行うかどうか
 	
-	const STANDARD_PRICE = 'selling';		// 通常価格
+	const REGULAR_PRICE = 'regular';		// 通常価格
 	const ORDER_STATUS_CLOSE = 900;			// 受注処理終了
 	const PRICE_OBJ_ID = "eclib";		// 価格計算オブジェクトID
 	const DEFAULT_COUNTRY_ID = 'JPN';	// デフォルト国ID
@@ -678,7 +678,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				if (!$fetchedRow['ht_visible']) $priceAvailable = false;		// 商品が表示不可のときは価格を無効とする
 				
 				// 画像価格情報を取得
-				$ret = self::$_mainDb->getPhotoInfoWithPrice($productId, $productClass, $productType, ec_mainCommonDef::STANDARD_PRICE, $this->_langId, $row);
+				$ret = self::$_mainDb->getPhotoInfoWithPrice($productId, $productClass, $productType, ec_mainCommonDef::REGULAR_PRICE, $this->_langId, $fetchedRow['cu_id'], $row);
 				
 				// 画像詳細へのリンク
 				$url = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PHOTO_ID . '=' . $photoId;
@@ -698,7 +698,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				if (!$fetchedRow['pt_visible']) $priceAvailable = false;		// 商品が表示不可のときは価格を無効とする
 				
 				// 商品価格情報を取得
-				$ret = self::$_mainDb->getProductByProductId($productId, $this->_langId, $row, $imageRows);
+				$ret = self::$_mainDb->getProductByProductId($productId, $this->_langId, $fetchedRow['cu_id'], $row, $imageRows);
 				
 				// 商品詳細へのリンク
 				$url = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $productId;
@@ -724,7 +724,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 
 			// 価格作成
 			$this->ecObj->setCurrencyType($currency, $this->_langId);		// 通貨設定
-			$this->ecObj->setTaxType($taxType, $this->_langId);		// 税種別設定
+			$this->ecObj->setTaxType($taxType);		// 税種別設定
 			$unitPrice = $this->ecObj->getPriceWithTax($price, $dispUnitPrice);	// 税込み価格取得
 			$dispUnitPriceNoSign = $dispUnitPrice;
 			$dispUnitPrice = $prePrice . $dispUnitPrice . $postPrice;
