@@ -535,7 +535,7 @@ class ec_mainBaseWidgetContainer extends BaseWidgetContainer
 				if (!$fetchedRow['ht_visible']) $priceAvailable = false;		// 商品が表示不可のときは価格を無効とする
 				
 				// 画像価格情報を取得
-				$ret = self::$_mainDb->getPhotoInfoWithPrice($productId, $productClass, $productType, ec_mainCommonDef::STANDARD_PRICE, $this->_langId, $row);
+				$ret = self::$_mainDb->getPhotoInfoWithPrice($productId, $productClass, $productType, ec_mainCommonDef::REGULAR_PRICE, $this->_langId, $fetchedRow['cu_id'], $row);
 				break;
 			case ec_mainCommonDef::PRODUCT_CLASS_DEFAULT:	// 一般商品のとき
 				// 商品内容
@@ -549,7 +549,7 @@ class ec_mainBaseWidgetContainer extends BaseWidgetContainer
 				if (!$fetchedRow['pt_visible']) $priceAvailable = false;		// 商品が表示不可のときは価格を無効とする
 				
 				// 商品価格情報を取得
-				$ret = self::$_mainDb->getProductByProductId($productId, $this->_langId, $row, $imageRows);
+				$ret = self::$_mainDb->getProductByProductId($productId, $this->_langId, $fetchedRow['cu_id'], $row, $imageRows);
 				break;
 		}
 		
@@ -561,7 +561,7 @@ class ec_mainBaseWidgetContainer extends BaseWidgetContainer
 
 			// 価格作成
 			self::$_ecObj->setCurrencyType($currency, $this->_langId);		// 通貨設定
-			self::$_ecObj->setTaxType($taxType, $this->_langId);		// 税種別設定
+			self::$_ecObj->setTaxType($taxType);		// 税種別設定
 			$unitPrice = self::$_ecObj->getPriceWithTax($price, $dispUnitPrice);	// 税込み価格取得
 			$dispUnitPrice = $prePrice . $dispUnitPrice . $postPrice;
 		} else {
@@ -659,7 +659,7 @@ class ec_mainBaseWidgetContainer extends BaseWidgetContainer
 				if (!$fetchedRow['ht_visible']) $priceAvailable = false;		// 商品が表示不可のときは価格を無効とする
 				
 				// 画像価格情報を取得
-				$ret = self::$_mainDb->getPhotoInfoWithPrice($productId, $productClass, $productType, ec_mainCommonDef::STANDARD_PRICE, $this->_langId, $row);
+				$ret = self::$_mainDb->getPhotoInfoWithPrice($productId, $productClass, $productType, ec_mainCommonDef::REGULAR_PRICE, $this->_langId, $fetchedRow['cu_id'], $row);
 				
 				// 画像詳細へのリンク
 				$url = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PHOTO_ID . '=' . $photoId;
@@ -686,7 +686,7 @@ class ec_mainBaseWidgetContainer extends BaseWidgetContainer
 				if (!$fetchedRow['pt_visible']) $priceAvailable = false;		// 商品が表示不可のときは価格を無効とする
 				
 				// 商品価格情報を取得
-				$ret = self::$_mainDb->getProductByProductId($productId, $this->_langId, $row, $imageRows);
+				$ret = self::$_mainDb->getProductByProductId($productId, $this->_langId, $fetchedRow['cu_id'], $row, $imageRows);
 				
 				// 商品詳細へのリンク
 				$url = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_PRODUCT_ID . '=' . $productId;
@@ -723,7 +723,7 @@ class ec_mainBaseWidgetContainer extends BaseWidgetContainer
 
 			// 価格作成
 			self::$_ecObj->setCurrencyType($currency, $this->_langId);		// 通貨設定
-			self::$_ecObj->setTaxType($taxType, $this->_langId);		// 税種別設定
+			self::$_ecObj->setTaxType($taxType);		// 税種別設定
 			$unitPrice = self::$_ecObj->getPriceWithTax($price, $dispUnitPrice);	// 税込み価格取得
 			$dispUnitPrice = $prePrice . $dispUnitPrice . $postPrice;
 		} else {
