@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: s_jquery_menuWidgetContainer.php 4865 2012-04-20 10:03:31Z fishbone $
+ * @version    SVN: $Id: s_jquery_menuWidgetContainer.php 4946 2012-06-08 01:41:44Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -94,10 +94,7 @@ class s_jquery_menuWidgetContainer extends BaseWidgetContainer
 		$title			= $this->targetObj->title;			// リストタイトル
 		$this->theme	= $this->targetObj->theme;		// メニューのテーマ
 		$insetList		= $this->targetObj->insetList;		// インセットリスト形式で表示するかどうか
-//		$limitUser	= $this->targetObj->limitUser;// ユーザを制限するかどうか
 
-		// ユーザ制限があるときはログイン時のみ表示
-//		if (!$limitUser || $this->gEnv->isCurrentUserLogined()){
 		// メニュー作成
 		$menuHtml = $this->createMenu($menuId, 0, 0, $tmp);
 			
@@ -183,7 +180,7 @@ class s_jquery_menuWidgetContainer extends BaseWidgetContainer
 				}
 				
 				// メニュー項目を作成
-				$name = $row['md_name'];
+				$name = $this->getCurrentLangString($row['md_name']);
 				if (empty($name)) continue;
 				
 				switch ($row['md_type']){
