@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: s_photoslideWidgetContainer.php 4725 2012-02-29 23:27:26Z fishbone $
+ * @version    SVN: $Id: s_photoslideWidgetContainer.php 4868 2012-04-20 10:05:13Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -201,7 +201,7 @@ class s_photoslideWidgetContainer extends BaseWidgetContainer
 		$imageUrl = $this->getUrl($this->getPhotoImageUrl($photoId));
 		
 		$dispTitle = $this->convertToDispString($title);
-		$imageTag = '<a href="' . $this->convertUrlToHtmlEntity($urlLink) . '" rel="external"><img src="' . $this->convertUrlToHtmlEntity($imageUrl) . '" alt="' . $dispTitle . '" title="' . $dispTitle . '" /></a>';
+		$imageTag = '<a href="' . $this->convertUrlToHtmlEntity($urlLink) . '" data-ajax="false"><img src="' . $this->convertUrlToHtmlEntity($imageUrl) . '" alt="' . $dispTitle . '" title="' . $dispTitle . '" /></a>';
 		$row = array(
 			'image_tag' => $imageTag			// アルバムのサムネール画像
 		);
